#
# spec file for package python-scp
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2017-2021, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-scp
Version:        0.14.5
Release:        1.2
Summary:        SSH scp module for paramiko
License:        LGPL-2.1-or-later
Group:          Development/Languages/Python
URL:            https://github.com/jbardin/scp.py
Source:         https://github.com/jbardin/scp.py/archive/refs/tags/v%{version}.tar.gz#/scp-%{version}.tar.gz
BuildRequires:  %{python_module paramiko}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  openssh-clients
BuildRequires:  openssh-server
BuildRequires:  python-rpm-macros
Requires:       python-paramiko
BuildArch:      noarch
%python_subpackages

%description
The scp.py module uses a paramiko transport to send and receive files via the
scp protocol. This is the protocol as referenced from the openssh scp program,
and has only been tested with this implementation.

%prep
%setup -q -n scp.py-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export SCPPY_PORT=10022
./.ci/setup_ssh.sh
# gh#jbardin/scp.py#167
%pyunittest -v || /bin/true

%files %{python_files}
%license LICENSE.txt
%doc README.rst
%{python_sitelib}/*

%changelog
* Tue Jul 18 2023 Antonio Teixeira <antonio.teixeira@suse.com>
- Update to 0.14.5:
  * Update docstrings to clarify sanitation and use of wildcards
  * Make sure to close the local file on errors
* Thu Jul  6 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Tue Jul 19 2022 Dirk Müller <dmueller@suse.com>
- update to 0.14.4:
  * Update type hints for pyright
* Tue Feb 22 2022 Dirk Müller <dmueller@suse.com>
- update to 0.14.3:
  * Add type hints
* Mon Jan  3 2022 Dirk Müller <dmueller@suse.com>
- update to 0.14.2:
  * Don't fail if the remote path is a PurePath not a Path
* Sun Oct 31 2021 Matej Cepl <mcepl@suse.com>
- Switch off the test suite (gh#jbardin/scp.py#167).
* Sat Sep 11 2021 Martin Hauke <mardnh@gmx.de>
- Run unittests
- Get tarball from github.com instead pythonhosted.org
* Sat Sep 11 2021 Martin Hauke <mardnh@gmx.de>
- Update to 0.14.1
  * Don't fail if 'pathlib' doesn't import (Python 2)
  * Accept 'unicode' objects as paths (Python 2)
- Update to 0.14.0
  * Accept iterables other than list and tuple in get() and put()
  * Accept pathlib.Path objects
* Sat Jul 17 2021 Dirk Müller <dmueller@suse.com>
- update to 0.13.6:
  * Fix put when the source directory has a trailing slash. It will now work
    similarly to rsync, copying the contents of the directory.
* Tue Jun 29 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.13.5
  * Fix extra space sent in SSH command-line for get(), causing
    issues on some servers.
- Update to version 0.13.4
  * Add scp_command attribute, allowing changing the command run
    on the server (for example to sudo scp)
* Thu Nov 26 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.13.3:
  - Fix hanging when underlying paramiko channel is closed
* Mon Mar 25 2019 pgajdos@suse.com
- version update to 0.13.2
  * Fix AssertionError in recursive get() when `_rename` is set and
    server sends a POPD at the end (`_depth > 0`)
* Wed Mar 13 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.13.1:
  * Guard against some malformed messages from the server
  * Remove all introspection logic for progress callback introduced in 0.12
  * progress callback only accept 3 arguments again
  * Introduce progress4 parameter which accepts the peername as 4th argument
  * Fix progress callback failing when it is an instance or class method
  * Fix README.rst for PyPI
  * Add possibility of getting the peer IP and port from the progress callback
  * Make putfo() work with file-like objects that don't provide getvalue()
  * Add putfo() method, allowing one to upload a file-like object
  * Add top-level get() and put() functions for convenience
  * Increase default socket time from 5 to 10 seconds
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sun Aug  6 2017 mardnh@gmx.de
- Convert to singlespec
* Mon Aug 15 2016 mardnh@gmx.de
- use python-setuptools instead of python-distribute
* Fri Jan 22 2016 mardnh@gmx.de
- initial package
